%define pyname  Shiboken2

%define qttarballdir pyside-setup-opensource-src

Name:           shiboken2
Version:        5.15.2
Release:        %mkrel 1
License:        LGPLv2+
Summary:        Creates the PySide2 bindings source files for Qt5
Group:          Development/KDE and Qt
URL:            https://wiki.qt.io/Qt_for_Python
Source0:        http://download.qt.io/official_releases/QtForPython/shiboken2/PySide2-%{version}-src/%{qttarballdir}-%{version}.tar.xz
Patch0:         shiboken2-5.12.2-python3-linking.patch

BuildRequires:  kf5-macros
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(Qt5XmlPatterns)

BuildRequires:  pkgconfig(python3)
BuildRequires:  python3-setuptools
BuildRequires:  python3-sphinx
BuildRequires:  python3-numpy-devel
BuildRequires:  pkgconfig(libxslt)
BuildRequires:  pkgconfig(libxml-2.0)

BuildRequires:  clang-devel
BuildRequires:  llvm-devel

Requires:       python3-%{name} = %{version}-%{release}

### Python 3

%description
The Shiboken2 Generator (A.K.A. shiboken) is the plugin that creates the
PySide2 bindings source files from Qt5 headers and auxiliary files
(typesystems, global.h and glue files).

%files
%{_bindir}/%{name}
%{_bindir}/shiboken_tool.py

#------------------------------------------------------------------------------

%package -n     python3-%{name}
Summary:        Creates the Python3 PySide2 bindings source files for Qt5
Group:          Development/KDE and Qt

%description -n python3-%{name}
The Shiboken2 Generator (A.K.A. shiboken) is the plugin that creates the
Python3 PySide2 bindings source files from Qt5 headers and auxiliary files
(typesystems, global.h and glue files).

%files -n python3-%{name}
%{python3_sitearch}/%{name}/
%{python3_sitearch}/%{name}_generator/

#------------------------------------------------------------------------------

%define py3major   5.15
%define py3libname %mklibname %{name}-python%{python3_version}_ %{py3major}

%package -n     %{py3libname}
Summary:        Shiboken2 Generator core library
Group:          System/Libraries

%description -n %{py3libname}
Python3 Shiboken2 Generator core library.

%files -n %{py3libname}
%{_libdir}/lib%{name}.cpython-%{python3_version_nodots}*.so.%{py3major}{,.*}

#------------------------------------------------------------------------------

%define py3libname_dev %mklibname %{name}-python%{python3_version} -d

%package -n     %{py3libname_dev}
Summary:        Development files for Python3 Shiboken2 Generator
Group:          Development/KDE and Qt
Requires:       %{name} = %{version}-%{release}
Requires:       %{py3libname} = %{version}-%{release}
Requires:       python3-%{name} = %{version}-%{release}
Requires:       clang-devel
Requires:       llvm-devel
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{py3libname_dev}
Development files for Python3 Shiboken2 Generator.

%files -n %{py3libname_dev}
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.cpython-%{python3_version_nodots}*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/cmake/%{pyname}-%{version}/

### End of Python 3
#------------------------------------------------------------------------------

%prep
%setup -q -n %{qttarballdir}-%{version}
%autopatch -p1

%build
%global _vpath_srcdir sources/shiboken2
%cmake -DBUILD_TESTS=OFF \
       -DUSE_PYTHON_VERSION=3
%cmake_build

%install
%cmake_install

# Python shebang
pathfix.py -pni "%{__python3} %{py3_shbang_opts}" %{buildroot}%{_bindir}/*


%changelog
* Sat Dec 05 2020 daviddavid <daviddavid> 5.15.2-1.mga8
+ Revision: 1652917
- New version 5.15.2

* Thu Nov 26 2020 tv <tv> 5.15.1-2.mga8
+ Revision: 1649617
- rebuild for llvm/clang 11.0

* Sat Sep 12 2020 daviddavid <daviddavid> 5.15.1-1.mga8
+ Revision: 1625260
- New version 5.15.1

* Thu Jun 04 2020 daviddavid <daviddavid> 5.15.0-1.mga8
+ Revision: 1590420
- New version 5.15.0

* Sun Mar 22 2020 tv <tv> 5.14.1-3.mga8
+ Revision: 1558875
- rebuild for llvm-10.0.0

* Thu Feb 20 2020 umeabot <umeabot> 5.14.1-2.mga8
+ Revision: 1545942
- Mageia 8 Mass Rebuild

* Thu Jan 30 2020 daviddavid <daviddavid> 5.14.1-1.mga8
+ Revision: 1485558
- New version 5.14.1

* Thu Jan 30 2020 daviddavid <daviddavid> 5.14.0-1.mga8
+ Revision: 1485475
- New version 5.14.0
+ wally <wally>
- build with new cmake macros

* Tue Sep 17 2019 tv <tv> 5.13.1-2.mga8
+ Revision: 1443080
- rebuild for clang-9.0

* Sun Sep 15 2019 daviddavid <daviddavid> 5.13.1-1.mga8
+ Revision: 1440995
- New version 5.13.1
- Remove merged upstream patch

* Sat Aug 03 2019 daviddavid <daviddavid> 5.13.0-2.mga8
+ Revision: 1427001
- add upstream patch to fix qApp import of QCoreApplication

* Sat Jul 27 2019 daviddavid <daviddavid> 5.13.0-1.mga8
+ Revision: 1424520
- New version 5.13.0
- Now libmajor is 5.13

* Mon Apr 15 2019 daviddavid <daviddavid> 5.12.2-4.mga7
+ Revision: 1390767
- rebuild for new llvm/clang 8.0

* Sun Apr 07 2019 daviddavid <daviddavid> 5.12.2-3.mga7
+ Revision: 1386673
- devel pkg require clang-devel and llvm-devel

* Sun Apr 07 2019 daviddavid <daviddavid> 5.12.2-2.mga7
+ Revision: 1386649
- devel pkg require main pkg for /usr/bin/shiboken2

* Sun Apr 07 2019 daviddavid <daviddavid> 5.12.2-1.mga7
+ Revision: 1386637
- add patch to fix Python3 linking issue
- initial package shiboken2

